# Changelog

## [v0.3.3]

### Chores

- improve dataset download process and streamline the CI workflows

## [v0.3.2]

### API Changes

- change table backend default to `anndata_v1` for backward compatibility. This will be chaanged again when ngio `v0.2.x` is no longer supported.

### Bug Fixes

- fix [#13](https://github.com/fractal-analytics-platform/fractal-converters-tools/issues/13) (converters tools)
- fix [#88](https://github.com/fractal-analytics-platform/ngio/issues/88)
